﻿using System.Linq;

using Xamarin.Forms;

using Android.Content;
using Android.Content.PM;
using Android.Telephony;

using TestProject.Droid;

[assembly: Dependency(typeof(Dialer))]
namespace TestProject.Droid
{
    /// <summary>
    /// 다이얼러
    /// </summary>
    public class Dialer : IDialer
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 인텐트 이용 가능 여부 구하기 - IsIntentAvailable(context, intent)

        /// <summary>
        /// 인텐트 이용 가능 여부 구하기
        /// </summary>
        /// <param name="context">컨텍스트</param>
        /// <param name="intent">인텐트</param>
        /// <returns>인텐트 이용 가능 여부</returns>
        public static bool IsIntentAvailable(Context context, Intent intent)
        {
            PackageManager packageManager = context.PackageManager;

            var list = packageManager.QueryIntentServices (intent, 0).Union(packageManager.QueryIntentActivities(intent, 0));

            if(list.Any())
            {
                return true;
            }

            TelephonyManager manager = TelephonyManager.FromContext(context);

            return manager.PhoneType != PhoneType.None;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Instance
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 전화 걸기 - Dial(phoneNumber)

        /// <summary>
        /// 전화 걸기
        /// </summary>
        /// <param name="phoneNumber">전화 번호</param>
        /// <returns>처리 결과</returns>
        public bool Dial(string phoneNumber)
        {
            MainActivity context = MainActivity.Instance;

            if(context == null)
            {
                return false;
            }

            Intent intent = new Intent(Intent.ActionCall);

            intent.SetData(Android.Net.Uri.Parse("tel:" + phoneNumber));

            if(IsIntentAvailable(context, intent))
            {
                context.StartActivity (intent);

                return true;
            }

            return false;
        }

        #endregion
    }
}