﻿using System;
using System.Threading.Tasks;
using Windows.ApplicationModel.Calls;
using Windows.UI.Popups;

using Xamarin.Forms;

using TestProject.UWP;

[assembly: Dependency(typeof(Dialer))]
namespace TestProject.UWP
{
    /// <summary>
    /// 다이얼러
    /// </summary>
    public class Dialer : IDialer
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 전화 걸기 여부
        /// </summary>
        private bool dialled = false;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 전화 걸기 - Dial(phoneNumber)

        /// <summary>
        /// 전화 걸기
        /// </summary>
        /// <param name="phoneNumber">전화 번호</param>
        /// <returns>처리 결과</returns>
        public bool Dial(string phoneNumber)
        {
            Call(phoneNumber);

            return dialled;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 호출하기 - Call(phoneNumber)

        /// <summary>
        /// 호출하기
        /// </summary>
        /// <param name="phoneNumber">전화 번호</param>
        /// <returns>태스크</returns>
        private async Task Call(string phoneNumber)
        {
            PhoneLine phoneLine = await GetDefaultPhoneLineAsync();

            if(phoneLine != null)
            {
                phoneLine.Dial(phoneNumber, phoneNumber);

                dialled = true;
            }
            else
            {
                MessageDialog dialog = new MessageDialog("전화를 걸 수 없습니다.");

                await dialog.ShowAsync();

                dialled = false;
            }
        }

        #endregion
        #region 디폴트 전화선 구하기 - GetDefaultPhoneLineAsync()

        /// <summary>
        /// 디폴트 전화선 구하기
        /// </summary>
        /// <returns>전화선 태스크</returns>
        private async Task<PhoneLine> GetDefaultPhoneLineAsync()
        {
            PhoneCallStore phoneCallStore = await PhoneCallManager.RequestStoreAsync();

            Guid lineGUID = await phoneCallStore.GetDefaultLineAsync();

            return await PhoneLine.FromIdAsync(lineGUID);
        }

        #endregion
    }
}