﻿using System.Text;

namespace TestProject
{
    /// <summary>
    /// 전화 헬퍼
    /// </summary>
    public static class PhoneHelper
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 숫자 배열
        /// </summary>
        private static readonly string[] _digitArray =
        {
            "ABC", "DEF", "GHI", "JKL", "MNO", "PQRS", "TUV", "WXYZ"
        };

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 전화 번호 구하기 - GetPhoneNumber(source)

        /// <summary>
        /// 전화 번호 구하기
        /// </summary>
        /// <param name="source">소스 문자열</param>
        /// <returns>전화 번호</returns>
        public static string GetPhoneNumber(string source)
        {
            if(string.IsNullOrWhiteSpace(source))
            {
                return null;
            }

            source = source.ToUpperInvariant();

            StringBuilder stringBuilder = new StringBuilder();

            foreach(char character in source)
            {
                if (" -0123456789".Contains(character))
                {
                    stringBuilder.Append(character);
                }
                else
                {
                    int? result = GetNumber(character);

                    if(result != null)
                    {
                        stringBuilder.Append(result);
                    }
                    else
                    {
                        return null;
                    }
                }
            }

            return stringBuilder.ToString();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Private

        #region 포함 여부 구하기 - Contains(keyString, character)

        /// <summary>
        /// 포함 여부 구하기
        /// </summary>
        /// <param name="keyString">키 문자열</param>
        /// <param name="character">문자</param>
        /// <returns>포함 여부</returns>
        private static bool Contains(this string keyString, char character)
        {
            return keyString.IndexOf(character) >= 0;
        }

        #endregion
        #region 번호 구하기 - GetNumber(character)

        /// <summary>
        /// 번호 구하기
        /// </summary>
        /// <param name="character">문자</param>
        /// <returns>번호</returns>
        private static int? GetNumber(char character)
        {
            for(int i = 0; i < _digitArray.Length; i++)
            {
                if(_digitArray[i].Contains(character))
                {
                    return 2 + i;
                }
            }

            return null;
        }

        #endregion
    }
}